<?php
namespace BYOB\Admin\Settings;

class BatteryOptions {
    private const OPTION_KEY = 'byob_battery_options';
    private const DEFAULT_CSS = '/**
 * Battery Builder Frontend Styles
 * 
 * This CSS controls all the styling for the battery builder form and results.
 * Sections:
 * 1. Container Layout
 * 2. Selection Paths (Tab Buttons)
 * 3. Form Styles
 * 4. Radio & Checkbox Inputs
 * 5. Submit Button
 * 6. Results Grid
 * 7. Battery Cards
 * 8. Status Messages
 */

/* 1. Container Layout */
.battery-builder-container {
    max-width: 1200px;
    margin: 0 auto;
    padding: 20px;
}

/* 2. Selection Paths */
.selection-paths {
    display: flex;
    justify-content: center;
    gap: 20px;
    margin-bottom: 30px;
}

.path-selector {
    padding: 15px 30px;
    font-size: 1.1em;
    font-weight: bold;
    border: 2px solid #007bff;
    border-radius: 8px;
    background: #fff;
    color: #007bff;
    cursor: pointer;
    transition: all 0.3s ease;
}

.path-selector:hover {
    background: #f8f9fa;
    transform: translateY(-2px);
}

.path-selector.active {
    background: #007bff;
    color: #fff;
}

/* 3. Form Styles */
.battery-filter-form {
    background: #f5f5f5;
    padding: 20px;
    border-radius: 8px;
    margin-bottom: 30px;
    transition: all 0.3s ease;
    display: none;
}

.battery-filter-form.active {
    display: block;
}

.battery-filter-form.hidden {
    display: none;
}

.filter-group {
    margin-bottom: 20px;
}

.filter-group > label {
    display: block;
    font-weight: bold;
    margin-bottom: 10px;
    color: #333;
}

/* 4. Radio & Checkbox Inputs */
.radio-group,
.checkbox-group {
    display: flex;
    flex-wrap: wrap;
    gap: 15px;
}

.radio-group label,
.checkbox-group label {
    display: flex;
    align-items: center;
    cursor: pointer;
    padding: 12px 20px;
    background: #fff;
    border: 1px solid #ddd;
    border-radius: 4px;
    transition: all 0.3s ease;
    font-size: 1.1em;
}

.radio-group label:hover,
.checkbox-group label:hover {
    background: #f0f0f0;
}

.radio-group input[type="radio"],
.checkbox-group input[type="checkbox"] {
    margin-right: 8px;
}

.radio-group input[type="radio"]:checked + label {
    background: #007bff;
    color: #fff;
    border-color: #0056b3;
}

.checkbox-group input[type="checkbox"]:checked + label {
    background: #28a745;
    color: #fff;
    border-color: #218838;
}

/* 5. Submit Button */
.submit-group {
    margin-top: 30px;
    text-align: center;
}

.build-battery-btn {
    background: #28a745;
    color: #fff;
    border: none;
    padding: 15px 40px;
    font-size: 1.2em;
    font-weight: bold;
    border-radius: 30px;
    cursor: pointer;
    transition: all 0.3s ease;
    text-transform: uppercase;
    letter-spacing: 1px;
    box-shadow: 0 4px 6px rgba(0,0,0,0.1);
}

.build-battery-btn:hover {
    background: #218838;
    transform: translateY(-2px);
    box-shadow: 0 6px 8px rgba(0,0,0,0.15);
}

.build-battery-btn:active {
    transform: translateY(0);
    box-shadow: 0 2px 4px rgba(0,0,0,0.1);
}

/* 6. Results Grid */
.battery-grid {
    display: grid;
    grid-template-columns: repeat(auto-fill, minmax(250px, 1fr));
    gap: 30px;
    margin-top: 30px;
}

/* 7. Battery Cards */
.battery-item {
    background: #fff;
    border: 1px solid #ddd;
    border-radius: 8px;
    overflow: hidden;
    transition: transform 0.3s ease;
    box-shadow: 0 2px 5px rgba(0,0,0,0.1);
}

.battery-item:hover {
    transform: translateY(-5px);
    box-shadow: 0 5px 15px rgba(0,0,0,0.2);
}

.battery-image {
    width: 100%;
    aspect-ratio: 1;
    overflow: hidden;
}

.battery-image img {
    width: 100%;
    height: 100%;
    object-fit: cover;
}

.battery-title {
    padding: 15px;
    margin: 0;
    font-size: 1.2em;
    color: #333;
    text-align: center;
}

.battery-specs {
    padding: 0 15px 15px;
    display: flex;
    flex-wrap: wrap;
    gap: 10px;
    justify-content: center;
}

.battery-specs span,
.battery-specs .use-cases {
    background: #f5f5f5;
    padding: 5px 10px;
    border-radius: 4px;
    font-size: 0.9em;
    color: #666;
}

.battery-specs .use-cases {
    width: 100%;
    text-align: center;
    margin-top: 5px;
}

.battery-link {
    display: block;
    text-align: center;
    padding: 12px 20px;
    background: #007bff;
    color: #fff;
    text-decoration: none;
    transition: background-color 0.3s ease;
}

.battery-link:hover {
    background: #0056b3;
    color: #fff;
}

/* 8. Status Messages */
.loading,
.no-results,
.error {
    text-align: center;
    padding: 30px;
    background: #f5f5f5;
    border-radius: 8px;
    color: #666;
    font-style: italic;
}

.error {
    background: #f8d7da;
    color: #dc3545;
}

/* Responsive Adjustments */
@media (max-width: 768px) {
    .selection-paths {
        flex-direction: column;
        gap: 10px;
    }

    .path-selector {
        width: 100%;
    }

    .radio-group label,
    .checkbox-group label {
        width: 100%;
        justify-content: center;
    }

    .battery-grid {
        grid-template-columns: 1fr;
    }
}';
    
    public function init(): void {
        add_action('admin_menu', [$this, 'add_settings_page']);
        add_action('admin_init', [$this, 'register_settings']);
        add_action('admin_enqueue_scripts', [$this, 'enqueue_scripts']);
    }

    public function add_settings_page(): void {
        add_submenu_page(
            'edit.php?post_type=battery',
            __('Battery Options', 'build-your-own-battery'),
            __('Options', 'build-your-own-battery'),
            'manage_options',
            'battery-options',
            [$this, 'render_settings_page']
        );
    }

    public function register_settings(): void {
        register_setting(
            'byob_options',
            self::OPTION_KEY,
            [
                'type' => 'array',
                'sanitize_callback' => [$this, 'sanitize_options']
            ]
        );
    }

    public function sanitize_options($input) {
        $options = [];

        // Sanitize voltage options
        $options['voltage_options'] = isset($input['voltage_options']) 
            ? array_filter(array_map('sanitize_text_field', explode("\n", $input['voltage_options'])))
            : [];

        // Sanitize capacity options
        $options['capacity_options'] = isset($input['capacity_options'])
            ? array_filter(array_map('sanitize_text_field', explode("\n", $input['capacity_options'])))
            : [];

        // Sanitize C Rate options
        $options['c_rate_options'] = isset($input['c_rate_options'])
            ? array_filter(array_map('sanitize_text_field', explode("\n", $input['c_rate_options'])))
            : [];

        // Sanitize use cases
        $options['use_cases'] = isset($input['use_cases'])
            ? array_filter(array_map('sanitize_text_field', explode("\n", $input['use_cases'])))
            : [];

        // Sanitize custom CSS
        $options['custom_css'] = isset($input['custom_css'])
            ? wp_strip_all_tags($input['custom_css'])
            : self::DEFAULT_CSS;

        return $options;
    }

    public function get_options(): array {
        $defaults = [
            'voltage_options' => ['12V', '24V', '36V', '48V'],
            'capacity_options' => ['50Ah', '100Ah', '200Ah', '300Ah'],
            'c_rate_options' => ['50A', '100A', '200A', '300A'],
            'use_cases' => [],
            'custom_css' => self::DEFAULT_CSS
        ];

        $options = get_option(self::OPTION_KEY, []);
        return wp_parse_args($options, $defaults);
    }

    public function render_settings_page(): void {
        if (!current_user_can('manage_options')) {
            return;
        }

        $options = $this->get_options();
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <form action="options.php" method="post">
                <?php
                settings_fields('byob_options');
                do_settings_sections('byob_options');
                ?>
                
                <table class="form-table">
                    <tr>
                        <th scope="row"><?php _e('Voltage Options', 'build-your-own-battery'); ?></th>
                        <td>
                            <textarea name="<?php echo esc_attr(self::OPTION_KEY); ?>[voltage_options]" rows="4" class="large-text"><?php echo esc_textarea(implode("\n", $options['voltage_options'])); ?></textarea>
                            <p class="description"><?php _e('Enter one voltage option per line (e.g., 12V)', 'build-your-own-battery'); ?></p>
                        </td>
                    </tr>
                    
                    <tr>
                        <th scope="row"><?php _e('Capacity Options', 'build-your-own-battery'); ?></th>
                        <td>
                            <textarea name="<?php echo esc_attr(self::OPTION_KEY); ?>[capacity_options]" rows="4" class="large-text"><?php echo esc_textarea(implode("\n", $options['capacity_options'])); ?></textarea>
                            <p class="description"><?php _e('Enter one capacity option per line (e.g., 100Ah)', 'build-your-own-battery'); ?></p>
                        </td>
                    </tr>

                    <tr>
                        <th scope="row"><?php _e('C Rate Options', 'build-your-own-battery'); ?></th>
                        <td>
                            <textarea name="<?php echo esc_attr(self::OPTION_KEY); ?>[c_rate_options]" rows="4" class="large-text"><?php echo esc_textarea(implode("\n", $options['c_rate_options'])); ?></textarea>
                            <p class="description"><?php _e('Enter one C Rate option per line (e.g., 100A)', 'build-your-own-battery'); ?></p>
                        </td>
                    </tr>
                    
                    <tr>
                        <th scope="row"><?php _e('Use Cases', 'build-your-own-battery'); ?></th>
                        <td>
                            <textarea name="<?php echo esc_attr(self::OPTION_KEY); ?>[use_cases]" rows="4" class="large-text"><?php echo esc_textarea(implode("\n", $options['use_cases'])); ?></textarea>
                            <p class="description"><?php _e('Enter one use case per line', 'build-your-own-battery'); ?></p>
                        </td>
                    </tr>
                    
                    <tr>
                        <th scope="row"><?php _e('Custom CSS', 'build-your-own-battery'); ?></th>
                        <td>
                            <textarea name="<?php echo esc_attr(self::OPTION_KEY); ?>[custom_css]" rows="10" class="large-text code"><?php echo esc_textarea($options['custom_css']); ?></textarea>
                            <p class="description"><?php _e('Custom CSS for the battery builder frontend', 'build-your-own-battery'); ?></p>
                        </td>
                    </tr>
                </table>

                <?php submit_button(); ?>
            </form>
        </div>
        <?php
    }

    public function enqueue_scripts($hook): void {
        if ($hook !== 'battery_page_battery-options') {
            return;
        }

        // Enqueue admin settings CSS
        wp_enqueue_style(
            'byob-admin-settings',
            BYOB_PLUGIN_URL . 'assets/css/admin-settings.css',
            [],
            BYOB_VERSION
        );

        // Enqueue jQuery
        wp_enqueue_script('jquery');

        // Enqueue admin settings JS
        wp_enqueue_script(
            'byob-admin-settings',
            BYOB_PLUGIN_URL . 'assets/js/admin-settings.js',
            ['jquery'],
            BYOB_VERSION . '.' . time(), // Add timestamp to prevent caching during development
            true
        );

        // Localize script with necessary data
        wp_localize_script(
            'byob-admin-settings',
            'byobSettings',
            [
                'ajaxurl' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('byob_save_options'),
                'debug' => WP_DEBUG
            ]
        );
    }
} 